==> qtjambi-xml-5.15.14-sources.jar: io/qt/xml/QDomNotation.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML notation</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdomnotation.html">QDomNotation</a></p>
 */
public class QDomNotation extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomnotation.html#QDomNotation">QDomNotation::QDomNotation()</a></p>
     */
    public QDomNotation(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomNotation instance);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomnotation.html#QDomNotation-1">QDomNotation::QDomNotation(QDomNotation)</a></p>
     */
    public QDomNotation(io.qt.xml.@NonNull QDomNotation x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomNotation instance, io.qt.xml.QDomNotation x);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomnotation.html#operator-eq">QDomNotation::operator=(QDomNotation)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomNotation arg__1){
        assign_native_cref_QDomNotation(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomNotation(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomnotation.html#publicId">QDomNotation::publicId()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String publicId(){
        return publicId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String publicId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdomnotation.html#systemId">QDomNotation::systemId()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String systemId(){
        return systemId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String systemId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomNotation(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QDomNotation clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomNotation clone_native(long __this_nativeId);
}

==> qtjambi-xml-6.2.12-sources.jar: io/qt/xml/QDomNotation.java <==
package io.qt.xml;

import io.qt.*;


/**
 * <p>Represents an XML notation</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qdomnotation.html">QDomNotation</a></p>
 */
public class QDomNotation extends io.qt.xml.QDomNode
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnotation.html#QDomNotation">QDomNotation::QDomNotation()</a></p>
     */
    public QDomNotation(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QDomNotation instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnotation.html#QDomNotation-1">QDomNotation::QDomNotation(QDomNotation)</a></p>
     */
    public QDomNotation(io.qt.xml.@NonNull QDomNotation x){
        super((QPrivateConstructor)null);
        initialize_native(this, x);
    }
    
    private native static void initialize_native(QDomNotation instance, io.qt.xml.QDomNotation x);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnotation.html#operator-eq">QDomNotation::operator=(QDomNotation)</a></p>
     */
    @QtUninvokable
    public final void assign(io.qt.xml.@NonNull QDomNotation arg__1){
        assign_native_cref_QDomNotation(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QDomNotation(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnotation.html#publicId">QDomNotation::publicId()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String publicId(){
        return publicId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String publicId_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qdomnotation.html#systemId">QDomNotation::systemId()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String systemId(){
        return systemId_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String systemId_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDomNotation(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QDomNotation clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QDomNotation clone_native(long __this_nativeId);
}
